@@ -24,6 +24,11 @@
 #include <string.h>
 #include <limits.h>
 
+#include <functional> //std::hash
+#ifdef HAVE_SPARSEHASH
+#include <tr1/functional>
+#endif
+
 #define BITMASK(b)     (1 << ((b) % CHAR_BIT))
 #define BITSLOT(b)     ((b) / CHAR_BIT)
 #define BITSET(a, b)   ((a)[BITSLOT(b)] |= BITMASK(b))
@@ -58,9 +63,14 @@ public:
     //
     unsigned char *s;
 
+#ifdef HAVE_SPARSEHASH
+    DNANSeq() : bits(3), s(new unsigned char[1]) { *s = (1<<2); } // "N"
+#endif
     DNANSeq(int);
     DNANSeq(int, const char *);
     DNANSeq(int, unsigned char *);
+    DNANSeq(const DNANSeq& other);
+    DNANSeq& operator=(const DNANSeq& other);
     ~DNANSeq();
 
     char  operator[](int);
@@ -68,6 +78,17 @@ public:
     char *seq(char *);
     char *seq();
     char *subseq(char *, int, int);
+
+    bool operator== (const DNANSeq& other) const {
+        if (bits != other.bits)
+            return false;
+
+        unsigned int bytes = BITNSLOTS(bits);
+        for (unsigned int i = 0; i < bytes; i++)
+            if (s[i] != other.s[i])
+                return false;
+        return true;
+    }
 };
 
 #include <iostream>
@@ -78,42 +99,55 @@ using std::cin;
 using std::cout;
 using std::cerr;
 
+// Specialization for std::hash
+// Based on GCC
+namespace std {
+template<>
+struct hash<DNANSeq> {
+    size_t operator()(const DNANSeq& seq) const {
+        size_t __result = static_cast<size_t>(14695981039346656037ULL);
+        unsigned short int __bytes  = BITNSLOTS(seq.bits);
+        for (unsigned short int i = 0; i < __bytes; i++) {
+            __result ^= static_cast<size_t>(seq.s[i]);
+            __result *= static_cast<size_t>(1099511628211ULL);
+        }
+        return __result;
+    }
+};
+
+#ifdef HAVE_SPARSEHASH
+namespace tr1 {
+template<>
+struct hash<DNANSeq> {
+    size_t operator()(const DNANSeq& seq) const { return std::hash<DNANSeq>()(seq); }
+};
+}
+#endif
+}
+
 // namespace __gnu_cxx {
 //     template<>
 //     struct hash<DNANSeq *>
 //     {
-// 	size_t
-// 	operator()(DNANSeq *__s) const {
-// 	    unsigned long   __h = 0;
-// 	    unsigned int  bytes = BITNSLOTS(__s->bits);
-// 	    for (unsigned int i = 0; i < bytes; i++)
-// 		__h = 5 * __h + __s->s[i];
-// 	    return size_t(__h);
-// 	}
+//      size_t
+//      operator()(DNANSeq *__s) const {
+//          unsigned long   __h = 0;
+//          unsigned int  bytes = BITNSLOTS(__s->bits);
+//          for (unsigned int i = 0; i < bytes; i++)
+//              __h = 5 * __h + __s->s[i];
+//          return size_t(__h);
+//      }
 //     };
 // }
 
-struct hash_dnanseq {
-    size_t operator()(DNANSeq *__s) const
-    {
-	size_t __result = static_cast<size_t>(14695981039346656037ULL);
-	unsigned short int __bytes  = BITNSLOTS(__s->bits);
-	for (unsigned short int i = 0; i < __bytes; i++) {
-	    __result ^= static_cast<size_t>(__s->s[i]);
-	    __result *= static_cast<size_t>(1099511628211ULL);
-	}
-
-	return __result;
-    }
+/* struct hash_dnanseq {
+    // Deprecated
+    size_t operator()(const DNANSeq* seq) const {return std::hash<DNANSeq>{}(*seq);}
 };
 
 struct dnanseq_eqstr {
-    bool operator()(DNANSeq *s1, DNANSeq *s2) const {
-	unsigned int bytes = BITNSLOTS(s1->bits);
-	for (unsigned int i = 0; i < bytes; i++)
-	    if (s1->s[i] != s2->s[i]) return false;
-	return true;
-    }
-};
+    // Deprecated
+    bool operator()(const DNANSeq *s1, const DNANSeq *s2) const {return *s1 == *s2;}
+}; */
 
 #endif // __DNANSeq_H__
