@@ -30,15 +30,15 @@ public:
     uint   contiguity;
     double pct_id;
     AlignRes() {
-	this->gap_cnt    = 0;
+        this->gap_cnt    = 0;
         this->contiguity = 0;
-	this->pct_id     = 0.0;
+        this->pct_id     = 0.0;
     }
     AlignRes(string cigar, uint gapcnt, uint contiguity, double pct_id) {
-	this->cigar      = cigar;
-	this->gap_cnt    = gapcnt;
+        this->cigar      = cigar;
+        this->gap_cnt    = gapcnt;
         this->contiguity = contiguity;
-	this->pct_id     = pct_id;
+        this->pct_id     = pct_id;
     }
 };
 
@@ -83,7 +83,7 @@ class GappedAln {
     inline int swap(double *, dynprog *, int, int);
     int        trace_alignment(string, string);
 
- public:    
+ public:
     GappedAln();
     GappedAln(int i) : GappedAln(i, i) {};
     GappedAln(int, int);
@@ -125,7 +125,7 @@ GappedAln::GappedAln(int len_1, int len_2)
 
 GappedAln::~GappedAln()
 {
-    for (uint i = 0; i < this->_m; i++) {
+    for (uint i = 0; i < this->_m_size; i++) {
         delete [] this->matrix[i];
         delete [] this->path[i];
     }
@@ -139,33 +139,33 @@ GappedAln::init(int size_1, int size_2)
     //
     // Resize the underlying matrix and path arrays, if necessary.
     //
-    if ((size_1 + 1) > (int)_m_size || (size_2 + 1) > (int)_n_size) {
-	for (uint i = 0; i < this->_m_size; i++) {
-	    delete [] this->matrix[i];
-	    delete [] this->path[i];
-	}
+    if ((size_1 + 1) > (int)this->_m_size || (size_2 + 1) > (int)this->_n_size) {
+        for (uint i = 0; i < this->_m_size; i++) {
+            delete [] this->matrix[i];
+            delete [] this->path[i];
+        }
         if (this->_m_size > 0) {
             delete [] this->matrix;
             delete [] this->path;
         }
 
-	this->_m_size = size_1 + 1;
-	this->_n_size = size_2 + 1;
+        this->_m_size = size_1 + 1;
+        this->_n_size = size_2 + 1;
         //
         // Resize the arrays to be 25% larger than the requested size.
         //
         int new_size = this->_m_size > this->_n_size ? this->_m_size : this->_n_size;
         new_size += int((double) new_size * 0.25);
         this->_m_size = new_size;
-	this->_n_size = new_size;
+        this->_n_size = new_size;
 
-	this->matrix = new double * [this->_m_size];
-	for (uint i = 0; i < this->_m_size; i++)
-	    this->matrix[i] = new double [this->_n_size];
+        this->matrix = new double * [this->_m_size];
+        for (uint i = 0; i < this->_m_size; i++)
+            this->matrix[i] = new double [this->_n_size];
 
-	this->path = new AlignPath * [this->_m_size];
-	for (uint i = 0; i < this->_m_size; i++)
-	    this->path[i] = new AlignPath [this->_n_size];
+        this->path = new AlignPath * [this->_m_size];
+        for (uint i = 0; i < this->_m_size; i++)
+            this->path[i] = new AlignPath [this->_n_size];
     }
 
     //
@@ -189,7 +189,7 @@ GappedAln::align(string tag_1, string tag_2)
     // v [3] |
     //   ... |
     // [m-1] |
-    // 
+    //
 
     //
     // Initialize the first column and row of the dynamic programming
@@ -215,7 +215,7 @@ GappedAln::align(string tag_1, string tag_2)
     double  score_down, score_diag, score_right;
     double  scores[3];
     dynprog direction[3];
-    
+
     for (uint i = 1; i < this->_m; i++) {
         for (uint j = 1; j < this->_n; j++) {
             // Calculate the score:
@@ -268,7 +268,7 @@ GappedAln::align(string tag_1, string tag_2)
                     this->path[i][j].up   = false;
                     this->path[i][j].left = true;
                 }
-                
+
             } else if (scores[0] == scores[1]) {
                 //
                 // Two of the paths are equivalent.
@@ -276,7 +276,7 @@ GappedAln::align(string tag_1, string tag_2)
                 switch (direction[0]) {
                 case dynp_diag:
                     this->path[i][j].diag = true;
-                    
+
                     switch (direction[1]) {
                     case dynp_down:
                         this->path[i][j].up   = true;
@@ -291,7 +291,7 @@ GappedAln::align(string tag_1, string tag_2)
                     break;
                 case dynp_down:
                     this->path[i][j].up = true;
-                    
+
                     switch (direction[1]) {
                     case dynp_right:
                         this->path[i][j].diag  = false;
@@ -307,7 +307,7 @@ GappedAln::align(string tag_1, string tag_2)
                 default:
                 case dynp_right:
                     this->path[i][j].left = true;
-                    
+
                     switch (direction[1]) {
                     case dynp_diag:
                         this->path[i][j].diag = true;
@@ -321,7 +321,7 @@ GappedAln::align(string tag_1, string tag_2)
                     }
                     break;
                 }
-                
+
             } else {
                 //
                 // All paths equivalent.
@@ -336,8 +336,8 @@ GappedAln::align(string tag_1, string tag_2)
     // dump_alignment(tag_1, tag_2, matrix, path);
 
     if (this->trace_alignment(tag_1, tag_2))
-	return 1;
-    
+        return 1;
+
     return 0;
 }
 
@@ -365,7 +365,7 @@ compare_alignres(AlignRes a, AlignRes b)
             return (a.pct_id > b.pct_id);
 
     } else {
-	return (a.gap_cnt < b.gap_cnt);
+        return (a.gap_cnt < b.gap_cnt);
     }
 }
 
@@ -381,7 +381,7 @@ GappedAln::trace_alignment(string tag_1, string tag_2)
     // v [3] |
     //   ... |
     // [m-1] |
-    // 
+    //
     int    i, j, cnt, len, gaps, contiguity;
     double ident;
     string cigar;
@@ -390,7 +390,7 @@ GappedAln::trace_alignment(string tag_1, string tag_2)
     vector<AlignRes> alns;
     bool more_paths = true;
     bool seq_break  = false;
-    
+
     do {
         more_paths = false;
 
@@ -434,13 +434,13 @@ GappedAln::trace_alignment(string tag_1, string tag_2)
         gaps       = 0;
         contiguity = 0;
         seq_break  = false;
-	ident      = 0.0;
+        ident      = 0.0;
         i          = 0;
         while (i < len) {
             if (aln_1[i] != '-' && aln_2[i] != '-') {
                 cnt = 0;
                 do {
-		    if (aln_1[i] == aln_2[i]) ident++;
+                    if (aln_1[i] == aln_2[i]) ident++;
                     cnt++;
                     i++;
                     if (seq_break == false) contiguity++;
@@ -472,8 +472,8 @@ GappedAln::trace_alignment(string tag_1, string tag_2)
         }
 
         alns.push_back(AlignRes(cigar, gaps, contiguity, (ident / (double) len)));
-        
-	// cerr << aln_1 << " [" << cigar << ", contiguity: " << contiguity << ", gaps: " << gaps << "]\n"
+
+        // cerr << aln_1 << " [" << cigar << ", contiguity: " << contiguity << ", gaps: " << gaps << "]\n"
         //      << aln_2 << "\n";
 
     } while (more_paths);
@@ -492,7 +492,7 @@ GappedAln::result()
     return this->_aln;
 }
 
-int 
+int
 GappedAln::parse_cigar(vector<pair<char, uint> > &cigar)
 {
     char buf[id_len];
@@ -532,7 +532,7 @@ GappedAln::dump_alignment(string tag_1, string tag_2)
     // v [3] |
     //   ... |
     // [m-1] |
-    // 
+    //
 
     //
     // Output the score matrix.
@@ -587,7 +587,7 @@ GappedAln::dump_alignment(string tag_1, string tag_2)
     }
 
     cout << "\n";
-    
+
     return 0;
 }
 
