@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010, Julian Catchen <jcatchen@uoregon.edu>
+// Copyright 2010-2016, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -21,44 +21,77 @@
 //
 // input.cc -- routines to read various formats of data into the XXX data structure.
 //
-// Julian Catchen
-// jcatchen@uoregon.edu
-// University of Oregon
-//
-// $Id$
-//
 
 #include "input.h"
 
-Seq::Seq() { 
+Seq::Seq() {
     this->id       = NULL;
     this->seq      = NULL;
     this->qual     = NULL;
     this->loc_str  = NULL;
+    this->aln_type = pri_aln;
+    this->pct_aln  = 1.0;
 }
 
-Seq::Seq(const char *id, const char *seq) { 
+Seq::Seq(const Seq& other)
+    : loc(other.loc) {
+    if (other.id != NULL) {
+        id = new char[strlen(other.id)+1];
+        strcpy(id, other.id);
+    } else {
+        id = NULL;
+    }
+    if (other.seq != NULL) {
+        seq = new char[strlen(other.seq)+1];
+        strcpy(seq, other.seq);
+    } else {
+        seq = NULL;
+    }
+    if (other.qual != NULL) {
+        qual = new char[strlen(other.qual)+1];
+        strcpy(qual, other.qual);
+    } else {
+        qual = NULL;
+    }
+    if (other.loc_str != NULL) {
+        loc_str = new char[strlen(other.loc_str)+1];
+        strcpy(loc_str, other.loc_str);
+    } else {
+        loc_str = NULL;
+    }
+
+    pct_aln  = other.pct_aln;
+    aln_type = other.aln_type;
+}
+
+Seq::Seq(const char *id, const char *seq) {
     this->id       = new char[strlen(id)   + 1];
     this->seq      = new char[strlen(seq)  + 1];
     this->qual     = NULL;
     this->loc_str  = NULL;
 
-    strcpy(this->id,   id); 
+    strcpy(this->id,   id);
     strcpy(this->seq,  seq);
+
+    this->aln_type = pri_aln;
+    this->pct_aln  = 1.0;
 }
 
-Seq::Seq(const char *id, const char *seq, const char *qual)  { 
+Seq::Seq(const char *id, const char *seq, const char *qual)  {
     this->id       = new char[strlen(id)   + 1];
     this->seq      = new char[strlen(seq)  + 1];
     this->qual     = new char[strlen(qual) + 1];
     this->loc_str  = NULL;
 
-    strcpy(this->id,   id); 
-    strcpy(this->seq,  seq); 
-    strcpy(this->qual, qual); 
+    strcpy(this->id,   id);
+    strcpy(this->seq,  seq);
+    strcpy(this->qual, qual);
+
+    this->aln_type = pri_aln;
+    this->pct_aln  = 1.0;
 }
 
-Seq::Seq(const char *id, const char *seq, const char *qual, const char *chr, uint bp, strand_type strand)  { 
+Seq::Seq(const char *id, const char *seq, const char *qual, const char *chr, uint bp, strand_type strand)  {
     this->id      = new char[strlen(id)   + 1];
     this->qual    = new char[strlen(qual) + 1];
     this->loc_str = new char[strlen(chr)  + 15];
@@ -70,14 +103,74 @@ Seq::Seq(const char *id, const char *seq, const char *qual, const char *chr, uin
     sprintf(this->loc_str, "%s|%d|%c", chr, bp, strand == strand_plus ? '+' : '-');
 
     //
-    // Reverse complement sequences from the negative strand 
+    // Reverse complement sequences from the negative strand
     //
     if (strand == strand_plus) {
-	this->seq = new char[strlen(seq)  + 1];
-	strcpy(this->seq, seq);
+        this->seq = new char[strlen(seq)  + 1];
+        strcpy(this->seq, seq);
     } else {
-	this->seq = rev_comp(seq);
+        this->seq = rev_comp(seq);
     }
+
+    this->aln_type = pri_aln;
+    this->pct_aln  = 1.0;
+}
+
+Seq::Seq(const char *id, const char *seq, const char *qual, const char *chr, uint bp, strand_type strand, alnt aln_type, double pct_aln)  {
+    this->id      = new char[strlen(id)   + 1];
+    this->qual    = new char[strlen(qual) + 1];
+    this->loc_str = new char[strlen(chr)  + 15];
+
+    strcpy(this->id,   id);
+    strcpy(this->qual, qual);
+    this->loc.set(chr, bp, strand);
+
+    sprintf(this->loc_str, "%s|%d|%c", chr, bp, strand == strand_plus ? '+' : '-');
+
+    //
+    // Reverse complement sequences from the negative strand
+    //
+    if (strand == strand_plus) {
+        this->seq = new char[strlen(seq)  + 1];
+        strcpy(this->seq, seq);
+    } else {
+        this->seq = rev_comp(seq);
+    }
+
+    this->aln_type = aln_type;
+    this->pct_aln  = pct_aln;
+}
+
+void swap(Seq& s1, Seq& s2) {
+    char  *ptr;
+    alnt   a;
+    double p;
+
+    ptr = s1.id;
+    s1.id = s2.id;
+    s2.id = ptr;
+
+    ptr = s1.seq;
+    s1.seq = s2.seq;
+    s2.seq = ptr;
+
+    ptr = s1.qual;
+    s1.qual = s2.qual;
+    s2.qual = ptr;
+
+    ptr = s1.loc_str;
+    s1.loc_str = s2.loc_str;
+    s2.loc_str = ptr;
+
+    a = s1.aln_type;
+    s1.aln_type = s2.aln_type;
+    s2.aln_type = a;
+
+    p = s1.pct_aln;
+    s1.pct_aln = s2.pct_aln;
+    s2.pct_aln = p;
+
+    swap(s1.loc, s2.loc);
 }
 
 Input::Input() {
@@ -93,7 +186,7 @@ Input::Input(const char *path) {
     //
     this->fh.open(path, ifstream::in);
 
-    if (this->fh.fail()) 
+    if (this->fh.fail())
         cerr << "Error opening input file '" << path << "'\n";
 }
 
@@ -102,8 +195,8 @@ Input::~Input() {
     this->fh.close();
 }
 
-int 
-parse_tsv(const char *line, vector<string> &parts) 
+int
+parse_tsv(const char *line, vector<string> &parts)
 {
     const char  *p, *q;
     string part;
@@ -112,14 +205,14 @@ parse_tsv(const char *line, vector<string> &parts)
     p = line;
 
     do {
-	for (q = p; *q != '\t' && *q != '\0'; q++);
-	if (q - p == 0) 
-	    part = "";
-	else
-	    part.assign(p, (q - p));
-	parts.push_back(part);
+        for (q = p; *q != '\t' && *q != '\0'; q++);
+        if (q - p == 0)
+            part = "";
+        else
+            part.assign(p, (q - p));
+        parts.push_back(part);
 
-	p = q + 1;
+        p = q + 1;
     } while (*q != '\0');
 
     //for (size_t i = 0; i < parts.size(); i++)
@@ -129,8 +222,8 @@ parse_tsv(const char *line, vector<string> &parts)
     return 0;
 }
 
-int 
-parse_ssv(const char *line, vector<string> &parts) 
+int
+parse_ssv(const char *line, vector<string> &parts)
 {
     const char  *p, *q;
     string part;
@@ -139,14 +232,14 @@ parse_ssv(const char *line, vector<string> &parts)
     p = line;
 
     do {
-	for (q = p; *q != ' ' && *q != '\0'; q++);
-	if (q - p == 0) 
-	    part = "";
-	else
-	    part.assign(p, (q - p));
-	parts.push_back(string(part));
+        for (q = p; *q != ' ' && *q != '\0'; q++);
+        if (q - p == 0)
+            part = "";
+        else
+            part.assign(p, (q - p));
+        parts.push_back(string(part));
 
-	p = q + 1;
+        p = q + 1;
     } while (*q != '\0');
 
     return 0;
@@ -163,8 +256,8 @@ int read_line(ifstream &fh, char **line, int *size) {
     // Make sure we read the entire line.
     //
     do {
-	fh.clear();
-	fh.getline(buf, max_len);
+        fh.clear();
+        fh.getline(buf, max_len);
 
         blen = strlen(buf);
         if (blen + llen <= (*size) - 1) {
@@ -179,7 +272,7 @@ int read_line(ifstream &fh, char **line, int *size) {
     } while (fh.fail() && !fh.bad() && !fh.eof());
 
     if (fh.eof() || fh.bad())
-	return 0;
+        return 0;
 
     return 1;
 }
@@ -197,14 +290,14 @@ int read_gzip_line(gzFile &fh, char **line, int *size) {
     // Make sure we read the entire line.
     //
     do {
-	if (gzgets(fh, buf, max_len) == NULL) break;
+        if (gzgets(fh, buf, max_len) == NULL) break;
 
         blen = strlen(buf);
 
-	if (blen > 0 && buf[blen - 1] == '\n') {
-	    eol = true;
-	    buf[blen - 1] = '\0';
-	}
+        if (blen > 0 && buf[blen - 1] == '\n') {
+            eol = true;
+            buf[blen - 1] = '\0';
+        }
 
         if (blen + llen <= (*size) - 1) {
             strcat(*line, buf);
@@ -218,7 +311,7 @@ int read_gzip_line(gzFile &fh, char **line, int *size) {
     } while (!gzeof(fh) && !eol);
 
     if (gzeof(fh))
-	return 0;
+        return 0;
 
     return 1;
 }
@@ -229,18 +322,18 @@ is_comment(const char *line)
     const char *p = line;
 
     while (*p != '\0')
-	switch(*p) {
-	case '#':
-	    return true;
-	    break;
-	case ' ':
-	case '\t':
-	    p++;
-	    break;
-	default:
-	    return false;
-	    break;
-	}
+        switch(*p) {
+        case '#':
+            return true;
+            break;
+        case ' ':
+        case '\t':
+            p++;
+            break;
+        default:
+            return false;
+            break;
+        }
 
     return false;
 }
