@@ -27,6 +27,7 @@
 #include <omp.h>    // OpenMP library
 #endif
 #include <getopt.h> // Process command-line options
+#include <time.h>
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
@@ -66,8 +67,11 @@ using google::sparse_hash_map;
 #include "kmers.h"
 #include "stacks.h"
 #include "locus.h"
+#include "GappedAln.h"
+#include "kmers.h"
 #include "sql_utilities.h"
 #include "utils.h"
+#include "aln_utils.h"
 
 #ifdef HAVE_SPARSEHASH
 typedef sparse_hash_map<const char *, vector<pair<int, allele_type> >, hash_charptr, eqstr> HashMap;
@@ -75,17 +79,21 @@ typedef sparse_hash_map<const char *, vector<pair<int, allele_type> >, hash_char
 typedef unordered_map<const char *, vector<pair<int, allele_type> >, hash_charptr, eqstr> HashMap;
 #endif
 
-void help( void );
-void version( void );
-int  parse_command_line(int, char**);
-int  populate_hash(map<int, Locus *> &, HashMap &, vector<char *> &, int);
-int  find_matches_by_sequence(map<int, Locus *> &, map<int, QLocus *> &);
-int  find_matches_by_genomic_loc(map<int, Locus *> &, map<int, QLocus *> &);
-int  verify_sequence_match(map<int, Locus *> &, QLocus *, set<int> &, map<string, vector<string> > &, uint, unsigned long &, unsigned long &);
-int  verify_genomic_loc_match(Locus *, QLocus *, set<string> &, unsigned long &);
-int  generate_query_haplotypes(Locus *, QLocus *, set<string> &);
-int  impute_haplotype(string, vector<pair<allele_type, string> > &, string &);
-bool compare_dist(pair<int, int>, pair<int, int>);
-int  write_matches(string, map<int, QLocus *> &);
+void   help( void );
+void   version( void );
+int    parse_command_line(int, char**);
+int    populate_hash(map<int, Locus *> &, HashMap &, vector<char *> &, int);
+int    find_matches_by_sequence(map<int, Locus *> &, map<int, QLocus *> &);
+int    find_matches_by_genomic_loc(map<int, Locus *> &, map<int, QLocus *> &);
+int    verify_sequence_match(map<int, Locus *> &, QLocus *, set<int> &, map<string, vector<string> > &, uint, unsigned long &, unsigned long &);
+int    search_for_gaps(map<int, Locus *> &, map<int, QLocus *> &, KmerHashMap &, map<int, pair<allele_type, int> > &, double);
+bool   verify_gapped_match(map<int, Locus *> &, QLocus *, set<int> &, map<allele_type, map<allele_type, AlignRes> > &, uint &, uint &, uint &, uint &, uint &);
+int    verify_genomic_loc_match(Locus *, QLocus *, set<string> &, unsigned long &);
+string generate_query_allele(Locus *, Locus *, allele_type);
+bool   match_alleles(allele_type, allele_type);
+int    generate_query_haplotypes(Locus *, QLocus *, set<string> &);
+int    impute_haplotype(string, vector<pair<allele_type, string> > &, string &);
+bool   compare_dist(pair<int, int>, pair<int, int>);
+int    write_matches(string, map<int, QLocus *> &);
 
 #endif // __SSTACKS_H__
