@@ -78,12 +78,12 @@ int main (int argc, char* argv[]) {
          << "  Max number of stacks allowed per de novo locus: " << max_subgraph << "\n"
          << "  Deleveraging algorithm: " << (deleverage_stacks ? "enabled" : "disabled") << "\n"
          << "  Removal algorithm: " << (remove_rep_stacks ? "enabled" : "disabled") << "\n"
-         << "  Model type: "; 
+         << "  Model type: ";
     switch (model_type) {
     case snp:
         cerr << "SNP\n";
         break;
-    case fixed: 
+    case fixed:
         cerr << "Fixed\n";
         break;
     case bounded:
@@ -94,7 +94,7 @@ int main (int argc, char* argv[]) {
          << "  Gapped alignments: " << (gapped_alignments ? "enabled" : "disabled") << "\n";
 
     //
-    // Set limits to call het or homozygote according to chi-square distribution with one 
+    // Set limits to call het or homozygote according to chi-square distribution with one
     // degree of freedom:
     //   http://en.wikipedia.org/wiki/Chi-squared_distribution#Table_of_.CF.872_value_vs_p-value
     //
@@ -119,22 +119,21 @@ int main (int argc, char* argv[]) {
     omp_set_num_threads(num_threads);
     #endif
 
-    DNASeqHashMap     radtags;
-    vector<DNANSeq *> radtags_keys;
+    DNASeqHashMap*    radtags = new DNASeqHashMap();
     map<int, Rem *>   remainders;
     set<int>          merge_map;
     map<int, Stack *> unique;
 
-    load_radtags(in_file, radtags, radtags_keys);
+    load_radtags(in_file, *radtags);
 
-    reduce_radtags(radtags, unique, remainders);
+    reduce_radtags(*radtags, unique, remainders);
 
-    free_radtags_hash(radtags, radtags_keys);
+    delete radtags;
 
     // dump_unique_tags(unique);
 
     double cov_mean, cov_stdev, cov_max;
-    
+
     calc_coverage_distribution(unique, cov_mean, cov_stdev, cov_max);
     cerr << "Initial coverage mean: " << cov_mean << "; Std Dev: " << cov_stdev << "; Max: " << cov_max << "\n";
 
@@ -188,7 +187,7 @@ int main (int argc, char* argv[]) {
         calc_coverage_distribution(unique, remainders, merged, cov_mean, cov_stdev, cov_max);
         cerr << "After gapped alignments, coverage depth Mean: " << cov_mean << "; Std Dev: " << cov_stdev << "; Max: " << cov_max << "\n";
     }
-    
+
     //
     // Call the final consensus sequence and invoke the SNP model.
     //
@@ -223,15 +222,15 @@ merge_gapped_alns(map<int, Stack *> &unique, map<int, Rem *> &rem, map<int, Merg
             continue;
 
         tag_1 = it->second;
-	sort(tag_1->alns.begin(), tag_1->alns.end(), rank_alignments);
+        sort(tag_1->alns.begin(), tag_1->alns.end(), rank_alignments);
 
         //
         // No gapped alignments, or no optimal alignment for this stack, or
-	// this stack has already been set aside.
+        // this stack has already been set aside.
         //
         if (tag_1->masked || tag_1->alns.size() == 0)
             continue;
-	if (tag_1->alns.size() > 1 && tag_1->alns[0].pct_id == tag_1->alns[1].pct_id)
+        if (tag_1->alns.size() > 1 && tag_1->alns[0].pct_id == tag_1->alns[1].pct_id)
             continue;
 
         //
@@ -239,24 +238,24 @@ merge_gapped_alns(map<int, Stack *> &unique, map<int, Rem *> &rem, map<int, Merg
         // of tags are, reciprocal to each other..
         //
         tag_2 = merged[tag_1->alns[0].id];
-	sort(tag_2->alns.begin(), tag_2->alns.end(), rank_alignments);
+        sort(tag_2->alns.begin(), tag_2->alns.end(), rank_alignments);
 
-	if (tag_2->masked || tag_2->alns.size() == 0)
+        if (tag_2->masked || tag_2->alns.size() == 0)
             continue;
-	if (tag_2->alns.size() > 1 && tag_2->alns[0].pct_id == tag_2->alns[1].pct_id)
+        if (tag_2->alns.size() > 1 && tag_2->alns[0].pct_id == tag_2->alns[1].pct_id)
             continue;
 
         if (tag_1->id != (int)tag_2->alns[0].id)
             continue;
 
-	cigar_1 = invert_cigar(tag_1->alns[0].cigar);
+        cigar_1 = invert_cigar(tag_1->alns[0].cigar);
         cigar_2 = tag_2->alns[0].cigar;
 
         if (cigar_1 == cigar_2) {
             parse_cigar(tag_1->alns[0].cigar.c_str(), cigar);
 
             //
-            // Check that the alignment still contains fewer than 
+            // Check that the alignment still contains fewer than
             // max_utag_dist mismatches.
             //
             if (dist(tag_1->con, tag_2->con, cigar) > max_utag_dist)
@@ -329,8 +328,8 @@ merge_gapped_alns(map<int, Stack *> &unique, map<int, Rem *> &rem, map<int, Merg
 
     merged = new_merged;
 
-    cerr << "  " << old_cnt << " stacks merged into " << new_cnt 
-         << " stacks; merged " << merge_cnt 
+    cerr << "  " << old_cnt << " stacks merged into " << new_cnt
+         << " stacks; merged " << merge_cnt
          << " gapped alignments.\n";
 
     return 0;
@@ -377,7 +376,7 @@ edit_gapped_seqs(map<int, Stack *> &unique, map<int, Rem *> &rem, MergedStack *t
     return 0;
 }
 
-int 
+int
 edit_gaps(vector<pair<char, uint> > &cigar, char *seq)
 {
     char *buf;
@@ -411,7 +410,7 @@ edit_gaps(vector<pair<char, uint> > &cigar, char *seq)
             // sequence down. Trim the final length to keep the read length consistent.
             //
             k = bp >= len ? len : bp;
-            
+
             strncpy(buf, seq + k, buf_size - 1);
             buf[buf_size - 1] = '\0';
             buf_len         = strlen(buf);
@@ -461,7 +460,7 @@ search_for_gaps(map<int, MergedStack *> &merged, double min_match_len)
     // our map to a vector of integer keys.
     //
     vector<int> keys;
-    for (it = merged.begin(); it != merged.end(); it++) 
+    for (it = merged.begin(); it != merged.end(); it++)
         keys.push_back(it->first);
 
     //
@@ -480,18 +479,18 @@ search_for_gaps(map<int, MergedStack *> &merged, double min_match_len)
     cerr << "  Searching with a k-mer length of " << kmer_len << " (" << num_kmers << " k-mers per read); " << min_hits << " k-mer hits required.\n";
 
     populate_kmer_hash(merged, kmer_map, kmer_map_keys, kmer_len);
- 
+
     #pragma omp parallel private(tag_1, tag_2)
     {
         KmerHashMap::iterator h;
         vector<char *> query_kmers;
         set<string>    uniq_kmers;
-	GappedAln     *aln = new GappedAln(con_len);
-	AlignRes       a;
+        GappedAln     *aln = new GappedAln(con_len);
+        AlignRes       a;
 
         initialize_kmers(kmer_len, num_kmers, query_kmers);
-        
-        #pragma omp for schedule(dynamic) 
+
+        #pragma omp for schedule(dynamic)
         for (uint i = 0; i < keys.size(); i++) {
             tag_1 = merged[keys[i]];
 
@@ -511,7 +510,7 @@ search_for_gaps(map<int, MergedStack *> &merged, double min_match_len)
             uniq_kmers.clear();
             for (int j = 0; j < num_kmers; j++)
                 uniq_kmers.insert(query_kmers[j]);
-            
+
             map<int, int> hits;
             //
             // Lookup the occurances of each k-mer in the kmer_map
@@ -548,9 +547,9 @@ search_for_gaps(map<int, MergedStack *> &merged, double min_match_len)
                     continue;
 
                 if (aln->align(tag_1->con, tag_2->con)) {
-		    a = aln->result();
-		    tag_1->alns.push_back(Aln(tag_2->id, a.cigar, a.pct_id, a.gap_cnt));
-		}
+                    a = aln->result();
+                    tag_1->alns.push_back(Aln(tag_2->id, a.cigar, a.pct_id, a.gap_cnt));
+                }
             }
         }
 
@@ -561,7 +560,7 @@ search_for_gaps(map<int, MergedStack *> &merged, double min_match_len)
             delete [] query_kmers[j];
         query_kmers.clear();
 
-	delete aln;
+        delete aln;
     }
 
     free_kmer_hash(kmer_map, kmer_map_keys);
@@ -604,9 +603,9 @@ merge_remainders(map<int, MergedStack *> &merged, map<int, Rem *> &rem)
     int min_hits = calc_min_kmer_matches(kmer_len, max_rem_dist, con_len, set_kmer_len ? true : false);
 
     cerr << "  Distance allowed between stacks: " << max_rem_dist
-	 << "; searching with a k-mer length of " << kmer_len << " (" << num_kmers << " k-mers per read); "
-	 << min_hits << " k-mer hits required.\n";
-    
+         << "; searching with a k-mer length of " << kmer_len << " (" << num_kmers << " k-mers per read); "
+         << min_hits << " k-mer hits required.\n";
+
     KmerHashMap    kmer_map;
     vector<char *> kmer_map_keys;
     populate_kmer_hash(merged, kmer_map, kmer_map_keys, kmer_len);
@@ -616,9 +615,9 @@ merge_remainders(map<int, MergedStack *> &merged, map<int, Rem *> &rem)
     {
         KmerHashMap::iterator h;
         vector<char *> rem_kmers;
-	char *buf = new char[con_len + 1];
+        char *buf = new char[con_len + 1];
 
-        #pragma omp for schedule(dynamic) 
+        #pragma omp for schedule(dynamic)
         for (uint j = 0; j < keys.size(); j++) {
             it = rem.find(keys[j]);
             Rem  *r = it->second;
@@ -695,7 +694,7 @@ merge_remainders(map<int, MergedStack *> &merged, map<int, Rem *> &rem)
         for (uint k = 0; k < rem_kmers.size(); k++)
             delete [] rem_kmers[k];
 
-	delete [] buf;
+        delete [] buf;
     }
 
     free_kmer_hash(kmer_map, kmer_map_keys);
@@ -738,7 +737,7 @@ call_alleles(MergedStack *mtag, vector<DNANSeq *> &reads, vector<read_type> &rea
             // Check to make sure the nucleotide at the location of this SNP is
             // of one of the two possible states the multinomial model called.
             //
-            if (base == (*snp)->rank_1 || base == (*snp)->rank_2) 
+            if (base == (*snp)->rank_1 || base == (*snp)->rank_2)
                 allele += base;
             else
                 break;
@@ -760,24 +759,24 @@ call_consensus(map<int, MergedStack *> &merged, map<int, Stack *> &unique, map<i
     //
     map<int, MergedStack *>::iterator it;
     vector<int> keys;
-    for (it = merged.begin(); it != merged.end(); it++) 
+    for (it = merged.begin(); it != merged.end(); it++)
         keys.push_back(it->first);
 
     int i;
     #pragma omp parallel private(i)
-    { 
+    {
         MergedStack *mtag;
         Stack       *utag;
         Rem         *r;
 
-        #pragma omp for schedule(dynamic) 
+        #pragma omp for schedule(dynamic)
         for (i = 0; i < (int) keys.size(); i++) {
             mtag = merged[keys[i]];
-            
+
             //
             // Create a two-dimensional array, each row containing one read. For
             // each unique tag that has been merged together, add the sequence for
-            // that tag into our array as many times as it originally occurred. 
+            // that tag into our array as many times as it originally occurred.
             //
             vector<int>::iterator j;
             vector<DNANSeq *>  reads;
@@ -792,7 +791,7 @@ call_consensus(map<int, MergedStack *> &merged, map<int, Stack *> &unique, map<i
                 }
             }
 
-            // For each remainder tag that has been merged into this Stack, add the sequence. 
+            // For each remainder tag that has been merged into this Stack, add the sequence.
             for (j = mtag->remtags.begin(); j != mtag->remtags.end(); j++) {
                 r = rem[*j];
 
@@ -825,8 +824,8 @@ call_consensus(map<int, MergedStack *> &merged, map<int, Stack *> &unique, map<i
                         SNP *snp    = new SNP;
                         snp->type   = snp_type_unk;
                         snp->col    = col;
-			snp->rank_1 = '-';
-			snp->rank_2 = '-';
+                        snp->rank_1 = '-';
+                        snp->rank_2 = '-';
                         mtag->snps.push_back(snp);
                         col++;
                     } while (col < mtag->gaps[cur_gap].end && col < length);
@@ -835,7 +834,7 @@ call_consensus(map<int, MergedStack *> &merged, map<int, Stack *> &unique, map<i
                     continue;
                 }
 
-                nuc['A'] = 0; 
+                nuc['A'] = 0;
                 nuc['G'] = 0;
                 nuc['C'] = 0;
                 nuc['T'] = 0;
@@ -861,7 +860,7 @@ call_consensus(map<int, MergedStack *> &merged, map<int, Stack *> &unique, map<i
                 //
                 // Search this column for the presence of a SNP
                 //
-                if (invoke_model) 
+                if (invoke_model)
                     switch(model_type) {
                     case snp:
                         call_multinomial_snp(mtag, col, nuc, true);
@@ -1106,8 +1105,8 @@ merge_stacks(map<int, Stack *> &unique, map<int, Rem *> &rem, map<int, MergedSta
 
     merged = new_merged;
 
-    cerr << "  " << old_cnt << " stacks merged into " << new_cnt 
-         << " stacks; deleveraged " << delev_cnt 
+    cerr << "  " << old_cnt << " stacks merged into " << new_cnt
+         << " stacks; deleveraged " << delev_cnt
          << " stacks; removed " << blist_cnt << " stacks.\n";
 
     return 0;
@@ -1206,9 +1205,9 @@ int
 remove_repetitive_stacks(map<int, Stack *> &unique, map<int, MergedStack *> &merged)
 {
     //
-    // If enabled, check the depth of coverage of each unique tag, and remove 
+    // If enabled, check the depth of coverage of each unique tag, and remove
     // from consideration any tags with depths greater than removal_trigger. These tags
-    // are likely to be multiple repetitive sites that have been merged together. 
+    // are likely to be multiple repetitive sites that have been merged together.
     // Because large stacks of unique tags are likely to also generate many one-off
     // sequencing error reads, remove all seqeunces that are a distance of one from
     // the RAD-Tag with high depth of coverage.
@@ -1275,7 +1274,7 @@ remove_repetitive_stacks(map<int, Stack *> &unique, map<int, MergedStack *> &mer
                 }
             }
         }
-        
+
         //
         // Merge these tags together into a new MergedStack object.
         //
@@ -1325,11 +1324,11 @@ remove_repetitive_stacks(map<int, Stack *> &unique, map<int, MergedStack *> &mer
     return 0;
 }
 
-int deleverage(map<int, Stack *> &unique, 
+int deleverage(map<int, Stack *> &unique,
                map<int, Rem *> &rem,
-               map<int, MergedStack *> &merged, 
-               set<int> &merge_list, 
-               int cohort_id, 
+               map<int, MergedStack *> &merged,
+               set<int> &merge_list,
+               int cohort_id,
                vector<MergedStack *> &deleveraged_tags) {
     set<int>::iterator it;
     vector<pair<int, int> >::iterator j;
@@ -1420,7 +1419,7 @@ int deleverage(map<int, Stack *> &unique,
     }
 
     //
-    // This set is sorted by definition. Check if there is more than a single 
+    // This set is sorted by definition. Check if there is more than a single
     // distance separating stacks.
     //
     if (dists.size() == 1) {
@@ -1504,7 +1503,7 @@ int calc_kmer_distance(map<int, MergedStack *> &merged, int utag_dist) {
     // OpenMP can't parallelize random access iterators, so we convert
     // our map to a vector of integer keys.
     vector<int> keys;
-    for (it = merged.begin(); it != merged.end(); it++) 
+    for (it = merged.begin(); it != merged.end(); it++)
         keys.push_back(it->first);
 
     //
@@ -1522,19 +1521,19 @@ int calc_kmer_distance(map<int, MergedStack *> &merged, int utag_dist) {
     int min_hits = calc_min_kmer_matches(kmer_len, utag_dist, con_len, set_kmer_len ? true : false);
 
     cerr << "  Distance allowed between stacks: " << utag_dist
-	 << "; searching with a k-mer length of " << kmer_len << " (" << num_kmers << " k-mers per read); "
-	 << min_hits << " k-mer hits required.\n";
+         << "; searching with a k-mer length of " << kmer_len << " (" << num_kmers << " k-mers per read); "
+         << min_hits << " k-mer hits required.\n";
 
     populate_kmer_hash(merged, kmer_map, kmer_map_keys, kmer_len);
- 
-    #pragma omp parallel private(tag_1, tag_2)
-    { 
-	KmerHashMap::iterator h;
-	vector<char *>        query_kmers;
-	
-	initialize_kmers(kmer_len, num_kmers, query_kmers);
 
-        #pragma omp for schedule(dynamic) 
+    #pragma omp parallel private(tag_1, tag_2)
+    {
+        KmerHashMap::iterator h;
+        vector<char *>        query_kmers;
+
+        initialize_kmers(kmer_len, num_kmers, query_kmers);
+
+        #pragma omp for schedule(dynamic)
         for (uint i = 0; i < keys.size(); i++) {
             tag_1 = merged[keys[i]];
 
@@ -1588,11 +1587,11 @@ int calc_kmer_distance(map<int, MergedStack *> &merged, int utag_dist) {
             sort(tag_1->dist.begin(), tag_1->dist.end(), compare_dist);
         }
 
-	//
-	// Free the k-mers we generated for this query
-	//
-	for (uint j = 0; j < query_kmers.size(); j++)
-	    delete [] query_kmers[j];
+        //
+        // Free the k-mers we generated for this query
+        //
+        for (uint j = 0; j < query_kmers.size(); j++)
+            delete [] query_kmers[j];
     }
 
     free_kmer_hash(kmer_map, kmer_map_keys);
@@ -1612,12 +1611,12 @@ int calc_distance(map<int, MergedStack *> &merged, int utag_dist) {
     // OpenMP can't parallelize random access iterators, so we convert
     // our map to a vector of integer keys.
     vector<int> keys;
-    for (it = merged.begin(); it != merged.end(); it++) 
+    for (it = merged.begin(); it != merged.end(); it++)
         keys.push_back(it->first);
 
     #pragma omp parallel private(i, j, tag_1, tag_2)
-    { 
-        #pragma omp for schedule(dynamic) 
+    {
+        #pragma omp for schedule(dynamic)
         for (i = 0; i < (int) keys.size(); i++) {
 
             tag_1 = merged[keys[i]];
@@ -1665,7 +1664,7 @@ int reduce_radtags(DNASeqHashMap &radtags, map<int, Stack *> &unique, map<int, R
     Rem   *r;
     Stack *u;
     int   global_id = 1;
-    
+
     for (it = radtags.begin(); it != radtags.end(); it++) {
         if (it->second.count() < min_merge_cov) {
             //
@@ -1675,7 +1674,7 @@ int reduce_radtags(DNASeqHashMap &radtags, map<int, Stack *> &unique, map<int, R
             //
             r     = new Rem;
             r->id = global_id;
-            r->add_seq(it->first);
+            r->add_seq(&it->first);
 
             for (uint i = 0; i < it->second.ids.size(); i++)
                 r->add_id(it->second.ids[i]);
@@ -1691,7 +1690,7 @@ int reduce_radtags(DNASeqHashMap &radtags, map<int, Stack *> &unique, map<int, R
             //
             u     = new Stack;
             u->id = global_id;
-            u->add_seq(it->first);
+            u->add_seq(&it->first);
 
             // Copy the original Fastq IDs from which this unique radtag was built.
             for (uint i = 0; i < it->second.ids.size(); i++)
@@ -1710,17 +1709,6 @@ int reduce_radtags(DNASeqHashMap &radtags, map<int, Stack *> &unique, map<int, R
     return 0;
 }
 
-int
-free_radtags_hash(DNASeqHashMap &radtags, vector<DNANSeq *> &radtags_keys)
-{
-    for (uint i = 0; i < radtags_keys.size(); i++)
-        delete radtags_keys[i];
-
-    radtags.clear();
-
-    return 0;
-}
-
 int
 calc_coverage_distribution(map<int, Stack *> &unique,
                            double &mean, double &stdev, double &max)
@@ -1820,7 +1808,7 @@ calc_coverage_distribution(map<int, Stack *> &unique,
 
 int
 calc_coverage_distribution(map<int, Stack *> &unique,
-                           map<int, Rem *> &rem, 
+                           map<int, Rem *> &rem,
                            map<int, MergedStack *> &merged,
                            double &mean, double &stdev, double &max)
 {
@@ -1831,7 +1819,7 @@ calc_coverage_distribution(map<int, Stack *> &unique,
     double s    = 0.0;
     double sum  = 0.0;
     double cnt  = 0.0;
-    
+
     mean  = 0.0;
     max   = 0.0;
     stdev = 0.0;
@@ -1911,8 +1899,8 @@ int count_raw_reads(map<int, Stack *> &unique, map<int, Rem *> &rem, map<int, Me
     return 0;
 }
 
-int 
-write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *> &r) 
+int
+write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *> &r)
 {
     map<int, MergedStack *>::iterator i;
     vector<int>::iterator      k;
@@ -1946,7 +1934,7 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
     string snp_file = out_path + in_file.substr(pos_1 + 1, (pos_2 - pos_1 - 1)) + ".snps.tsv";
     string all_file = out_path + in_file.substr(pos_1 + 1, (pos_2 - pos_1 - 1)) + ".alleles.tsv";
     string mod_file = out_path + in_file.substr(pos_1 + 1, (pos_2 - pos_1 - 1)) + ".models.tsv";
-    
+
     if (gzip) {
         tag_file += ".gz";
         snp_file += ".gz";
@@ -1970,7 +1958,7 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         #endif
         gz_mods = gzopen(mod_file.c_str(), "wb");
         if (!gz_mods) {
-            cerr << "Error: Unable to open gzipped tag file '" << tag_file << "': " << strerror(errno) << ".\n";
+            cerr << "Error: Unable to open gzipped model file '" << mod_file << "': " << strerror(errno) << ".\n";
             exit(1);
         }
         #if ZLIB_VERNUM >= 0x1240
@@ -2000,7 +1988,7 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         }
         mods.open(mod_file.c_str());
         if (mods.fail()) {
-            cerr << "Error: Unable to open tag file for writing.\n";
+            cerr << "Error: Unable to open model file for writing.\n";
             exit(1);
         }
         snps.open(snp_file.c_str());
@@ -2027,7 +2015,7 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
     time(&rawtime);
     timeinfo = localtime(&rawtime);
     strftime(date, 32, "%F %T", timeinfo);
-    log << "# ustacks version " << VERSION << "; generated on " << date << "\n"; 
+    log << "# ustacks version " << VERSION << "; generated on " << date << "\n";
     if (gzip) {
         gzputs(gz_tags, log.str().c_str());
         gzputs(gz_mods, log.str().c_str());
@@ -2055,17 +2043,17 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         tag_1->calc_likelihood();
 
         // First write the consensus sequence
-        sstr << "0"              << "\t" 
-             << sql_id           << "\t" 
+        sstr << "0"              << "\t"
+             << sql_id           << "\t"
              << tag_1->id        << "\t"
             //<< tag_1->cohort_id << "\t"
              << ""               << "\t" // chr
              << 0                << "\t" // bp
              << "+"              << "\t" // strand
-             << "consensus\t"    << "\t" 
-             << "\t" 
-             << tag_1->con         << "\t" 
-             << tag_1->deleveraged << "\t" 
+             << "consensus\t"    << "\t"
+             << "\t"
+             << tag_1->con         << "\t"
+             << tag_1->deleveraged << "\t"
              << tag_1->blacklisted << "\t"
              << tag_1->lumberjackstack << "\t"
              << tag_1->lnl << "\n";
@@ -2073,9 +2061,9 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         //
         // Write a sequence recording the output of the SNP model for each nucleotide.
         //
-        sstr << "0" << "\t" 
-             << sql_id << "\t" 
-             << tag_1->id << "\t" 
+        sstr << "0" << "\t"
+             << sql_id << "\t"
+             << tag_1->id << "\t"
             //<< "\t" // cohort_id
              << "\t"  // chr
              << "\t"  // bp
@@ -2095,7 +2083,7 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
                 break;
             }
         }
-        sstr << "\t" 
+        sstr << "\t"
              << "\t"
              << "\t"
              << "\t"
@@ -2121,10 +2109,10 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
                      << "\t" // chr
                      << "\t" // bp
                      << "\t" // strand
-                     << "primary\t" 
-                     << id << "\t" 
-                     << seq_ids[tag_2->map[j]] << "\t" 
-                     << tag_2->seq->seq(buf) 
+                     << "primary\t"
+                     << id << "\t"
+                     << seq_ids[tag_2->map[j]] << "\t"
+                     << tag_2->seq->seq(buf)
                      << "\t\t\t\t\n";
 
                 if (gzip) gzputs(gz_tags, sstr.str().c_str()); else tags << sstr.str();
@@ -2142,17 +2130,17 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
             total += rem->map.size();
 
             for (uint j = 0; j < rem->map.size(); j++)
-                sstr << "0"       << "\t" 
-                     << sql_id    << "\t" 
+                sstr << "0"       << "\t"
+                     << sql_id    << "\t"
                      << tag_1->id << "\t"
                     //<< "\t" // cohort_id
                      << "\t" // chr
                      << "\t" // bp
                      << "\t" // strand
                      << "secondary\t"
-                     << "\t" 
-                     << seq_ids[rem->map[j]] << "\t" 
-                     << rem->seq->seq(buf) 
+                     << "\t"
+                     << seq_ids[rem->map[j]] << "\t"
+                     << rem->seq->seq(buf)
                      << "\t\t\t\t\n";
 
             if (gzip) gzputs(gz_tags, sstr.str().c_str()); else tags << sstr.str();
@@ -2163,9 +2151,9 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         // Write out the model calls for each nucleotide in this locus.
         //
         for (s = tag_1->snps.begin(); s != tag_1->snps.end(); s++) {
-            sstr << "0"          << "\t" 
-                 << sql_id       << "\t" 
-                 << tag_1->id    << "\t" 
+            sstr << "0"          << "\t"
+                 << sql_id       << "\t"
+                 << tag_1->id    << "\t"
                  << (*s)->col    << "\t";
 
             switch((*s)->type) {
@@ -2181,8 +2169,8 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
             }
 
             sstr << std::fixed   << std::setprecision(2)
-                 << (*s)->lratio << "\t" 
-                 << (*s)->rank_1 << "\t" 
+                 << (*s)->lratio << "\t"
+                 << (*s)->rank_1 << "\t"
                  << (*s)->rank_2 << "\t\t\n";
         }
 
@@ -2194,11 +2182,11 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
         // the percentage of tags a particular allele occupies.
         //
         for (t = tag_1->alleles.begin(); t != tag_1->alleles.end(); t++) {
-            sstr << "0"         << "\t" 
-                 << sql_id      << "\t" 
-                 << tag_1->id   << "\t" 
-                 << (*t).first  << "\t" 
-                 << (((*t).second/total) * 100) << "\t" 
+            sstr << "0"         << "\t"
+                 << sql_id      << "\t"
+                 << tag_1->id   << "\t"
+                 << (*t).first  << "\t"
+                 << (((*t).second/total) * 100) << "\t"
                  << (*t).second << "\n";
         }
         if (gzip) gzputs(gz_alle, sstr.str().c_str()); else alle << sstr.str();
@@ -2267,11 +2255,11 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
     return 0;
 }
 
-int dump_stack_graph(string data_file, 
-                     map<int, Stack *> &unique, 
-                     map<int, MergedStack *> &merged, 
-                     vector<int> &keys, 
-                     map<int, map<int, double> > &dist_map, 
+int dump_stack_graph(string data_file,
+                     map<int, Stack *> &unique,
+                     map<int, MergedStack *> &merged,
+                     vector<int> &keys,
+                     map<int, map<int, double> > &dist_map,
                      map<int, set<int> > &cluster_map) {
     uint s, t;
     double d, scale, scaled_d;
@@ -2301,9 +2289,9 @@ int dump_stack_graph(string data_file,
          << "edge [fontsize=8.0 fontname=\"Arial\" color=\"#aaaaaa\"];\n";
 
     colors.push_back("red");
-    colors.push_back("blue"); 
-    colors.push_back("green"); 
-    colors.push_back("brown"); 
+    colors.push_back("blue");
+    colors.push_back("green");
+    colors.push_back("brown");
     colors.push_back("purple");
 
     map<int, set<int> >::iterator c;
@@ -2381,7 +2369,7 @@ int dump_unique_tags(map<int, Stack *> &u) {
 
         cerr << "UniqueTag UID: " << (*it).second->id << "\n"
              << "  Seq:       "   << c << "\n"
-             << "  IDs:       "; 
+             << "  IDs:       ";
 
         for (uint j = 0; j < it->second->map.size(); j++)
             cerr << it->second->map[j] << " ";
@@ -2405,9 +2393,9 @@ int dump_merged_tags(map<int, MergedStack *> &m) {
              << "  Consensus:  ";
         if (it->second->con != NULL)
             cerr << it->second->con << "\n";
-        else 
+        else
             cerr << "\n";
-        cerr << "  IDs:        "; 
+        cerr << "  IDs:        ";
 
         for (fit = it->second->utags.begin(); fit != it->second->utags.end(); fit++)
             cerr << (*fit) << " ";
@@ -2424,9 +2412,8 @@ int dump_merged_tags(map<int, MergedStack *> &m) {
     return 0;
 }
 
-int load_radtags(string in_file, DNASeqHashMap &radtags, vector<DNANSeq *> &radtags_keys) {
+int load_radtags(string in_file, DNASeqHashMap &radtags) {
     Input *fh = NULL;
-    DNANSeq *d;
 
     if (in_file_type == FileT::fasta)
         fh = new Fasta(in_file.c_str());
@@ -2449,8 +2436,10 @@ int load_radtags(string in_file, DNASeqHashMap &radtags, vector<DNANSeq *> &radt
     c.seq  = new char[max_len];
     c.qual = new char[max_len];
 
+    cerr << "Loading RAD-Tags...";
     while ((fh->next_seq(c)) != 0) {
-        if (i % 10000 == 0) cerr << "  Loading RAD-Tag " << i << "       \r";
+        if (i % 1000000 == 0 && i>0)
+            cerr << i/1000000 << "M...";
 
         prev_seql = seql;
         seql      = 0;
@@ -2464,32 +2453,26 @@ int load_radtags(string in_file, DNASeqHashMap &radtags, vector<DNANSeq *> &radt
                 corrected++;
             }
 
-        if (seql != prev_seql && prev_seql > 0) len_mismatch = true;
+        if (seql != prev_seql && prev_seql > 0)
+            len_mismatch = true;
 
-        d = new DNANSeq(seql, c.seq);
-
-        pair<DNASeqHashMap::iterator, bool> r;
-
-        r = radtags.insert(make_pair(d, HVal()));
-        (*r.first).second.add_id(i);
-        radtags_keys.push_back(d);
+        DNASeqHashMap::iterator element = radtags.insert({DNANSeq(seql, c.seq), HVal()}).first;
+        element->second.add_id(i);
         i++;
     }
-    cerr << "Loaded " << i << " RAD-Tags; inserted " << radtags.size() << " elements into the RAD-Tags hash map.\n";
+    cerr << "done\n";
 
     if (i == 0) {
         cerr << "Error: Unable to load data from '" << in_file.c_str() << "'.\n";
         exit(1);
     }
-
-    cerr << "  " << corrected << " reads contained uncalled nucleotides that were modified.\n";
-
     if (len_mismatch)
-        cerr << "  Warning: different sequence lengths detected, this will interfere with Stacks algorithms.\n";
+        cerr << "Warning: different sequence lengths detected, this will interfere with Stacks algorithms.\n";
+
+    cerr << "Loaded " << i << " RAD-Tags.\n"
+            "  Inserted " << radtags.size() << " elements into the RAD-Tags hash map.\n"
+            "  " << corrected << " reads contained uncalled nucleotides that were modified.\n";
 
-    //
-    // Close the file and delete the Input object.
-    //
     delete fh;
 
     return 0;
@@ -2509,7 +2492,7 @@ load_seq_ids(vector<char *> &seq_ids)
     else if (in_file_type == FileT::gzfastq)
         fh = new GzFastq(in_file.c_str());
 
-    cerr << "  Refetching sequencing IDs from " << in_file.c_str() << "... ";    
+    cerr << "  Refetching sequencing IDs from " << in_file.c_str() << "... ";
 
     char *id;
     Seq c;
@@ -2544,7 +2527,7 @@ calc_triggers(double cov_mean,
 //     //
 //     // Calculate the deleverage trigger. Assume RAD-Tags are selected from
 //     // the sample for sequencing randomly, forming a poisson distribution
-//     // representing the depths of coverage of RAD-Tags in the sample. Calculate 
+//     // representing the depths of coverage of RAD-Tags in the sample. Calculate
 //     // the trigger value that is larger than the depth of coverage of 99.9999% of stacks.
 //     //
 //     long double lambda = cov_mean;
@@ -2586,7 +2569,7 @@ long double factorial(int i) {
 
 int parse_command_line(int argc, char* argv[]) {
     int c;
-     
+
     while (1) {
         static struct option long_options[] = {
             {"help",             no_argument,       NULL, 'h'},
@@ -2619,13 +2602,13 @@ int parse_command_line(int argc, char* argv[]) {
 
         // getopt_long stores the option index here.
         int option_index = 0;
-     
+
         c = getopt_long(argc, argv, "GhHvdrgRA:L:U:f:o:i:m:e:p:t:M:N:K:k:T:X:x:", long_options, &option_index);
-     
+
         // Detect the end of the options.
         if (c == -1)
             break;
-     
+
         switch (c) {
         case 'h':
             help();
@@ -2730,7 +2713,7 @@ int parse_command_line(int argc, char* argv[]) {
             // getopt_long already printed an error message.
             help();
             break;
-     
+
         default:
             cerr << "Unknown command line option '" << (char) c << "'\n";
             help();
@@ -2767,10 +2750,10 @@ int parse_command_line(int argc, char* argv[]) {
         help();
     }
 
-    if (out_path.length() == 0) 
+    if (out_path.length() == 0)
         out_path = ".";
 
-    if (out_path.at(out_path.length() - 1) != '/') 
+    if (out_path.at(out_path.length() - 1) != '/')
         out_path += "/";
 
     if (model_type == fixed && barcode_err_freq == 0) {
@@ -2810,7 +2793,7 @@ void help() {
               << "    --gapped: preform gapped alignments between stacks.\n"
               << "    --max_gaps: number of gaps allowed between stacks before merging (default: 2).\n"
               << "    --min_aln_len: minimum length of aligned sequence in a gapped alignment (default: 0.80).\n\n"
-              << "  Model options:\n" 
+              << "  Model options:\n"
               << "    --model_type: either 'snp' (default), 'bounded', or 'fixed'\n"
               << "    For the SNP or Bounded SNP model:\n"
               << "      --alpha <num>: chi square significance level required to call a heterozygote or homozygote, either 0.1, 0.05 (default), 0.01, or 0.001.\n"
